@@ -6,7 +6,7 @@
 #include <QProcess>
 #include <QtGui/QCloseEvent>
 #include <QSettings>
-//#include <QDebug>
+#include <QDebug>
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -56,11 +56,21 @@ void MainWindow::makeStream(QString host, bool backcamera, bool video, QString p
     if(ui->tickqual->isChecked()){Jquality= "quality="+ui->qcontrol->text();}else{Jquality="";}   //necessary because the option kills quality, even if 100%
     if(video){
         if(backcamera){ qbcam = "0"; } else { qbcam = "1";}
-        if(outp!=3){ //filesink? no
-            if(outp==0){//VLC
-                midbits = "dsph264enc ! rtph264pay ! udpsink";
-                contextRun = "Open file in VLC";
-            } else if (outp==1){ //Xout
+        if(outp==3){ //filesink
+            QString filelocation = ui->filesinkname->text();
+            streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" ! ffmpegcolorspace ! jpegenc "+Jquality+" ! avimux ! filesink location=/home/user/MyDocs/.videos/"+filelocation+".avi";
+            notify("streaming to "+filelocation, false);
+        }
+        else if(outp==0){//VLC  //dont forget to delete file
+            write2file("/home/user/.httpstream", "#!/bin/bash\nread throwaway\nsleep 5\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: video/x-msvideo\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmpvid 2>/dev/null\nmkfifo /home/user/.tmpvid\ngst-launch v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" ! ffmpegcolorspace ! jpegenc "+Jquality+" ! filesink location=/home/user/.tmpvid >/dev/null &\ncat /home/user/.tmpvid");
+            executable("/home/user/.httpstream");
+            streamout = "socat TCP4-LISTEN:"+port+",reuseaddr,fork exec:/home/user/.httpstream",
+            notify("Open VLC:\nMedia-->Open Network Stream..., Type in:\nhttp://"+getIP()+":"+port, true);
+            notify("streaming", false);
+        }
+
+        else if(outp!=0 || outp!=3){ //VLC or filesink? no   //this is neccasary because vlc and localfile dont streamout normally
+            if (outp==1){ //Xout
                 midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
                 contextRun = "   from terminal, run: 'sh ~/Desktop/n900Xvideo.sh'";
             } else if (outp==2){//webcam
@@ -76,19 +86,21 @@ void MainWindow::makeStream(QString host, bool backcamera, bool video, QString p
             //more contextual instruction o how to run the file needed.
             notify("streaming", false);
         }
-        else if(outp==3){ //filesink
-            QString filelocation = ui->filesinkname->text();
-            streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" ! ffmpegcolorspace ! jpegenc "+Jquality+" ! avimux ! filesink location=/home/user/MyDocs/.videos/"+filelocation+".avi";
-            notify("streaming to "+filelocation, false);
-        }
+        ui->outWind->setText("...currently streaming...");
+        QProcess*proc = new QProcess();
+        proc->start(streamout);
+        //ui->outWind->append(proc->readAll()); //NOW JUST NEED TO PASS OUTPUT FROM GST-LAUNCH BACK INTO OUTWIND
     }
     else if (!video){
-        streamout = "gst-launch-0.10 pulsesrc ! audioconvert ! volume volume="+ui->vol->text()+" ! audioresample ! nokiaaacenc ! rtpmp4apay ! udpsink host="+host+" port="+port;
-    }
-    ui->outWind->setText("...currently streaming...");
-    QProcess*proc = new QProcess();
-    proc->start(streamout);
-    //ui->outWind->append(proc->readAll()); //NOW JUST NEED TO PASS OUTPUT FROM GST-LAUNCH BACK INTO OUTWIND
+        streamout = " ";
+        /*QString stream1 = "gst-launch-0.10 pulsesrc ! audioconvert ! volume volume="+ui->vol->text()+" ! audioresample ! nokiaaacenc ! rtpmp4apay";
+        write2file("/home/user/.httpstream", "#!/bin/bash\nread throwaway\nsleep 7\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: audio/mpeg\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmpvid 2>/dev/null\nmkfifo /home/user/.tmpvid\n"+stream1+" ! filesink location=/home/user/.tmpvid >/dev/null &\ncat /home/user/.tmpvid");
+        executable("/home/user/.httpstream");
+        streamout = "socat TCP4-LISTEN:"+port+",reuseaddr,fork exec:/home/user/.httpstream",
+        notify("Open VLC:\nMedia-->Open Network Stream..., Type in:\nhttp://"+getIP()+":"+port, true);
+        notify("streaming", false);*/
+
+    }   
  }
 
 void MainWindow::write2file(QString path, QString script){
@@ -100,44 +112,60 @@ void MainWindow::write2file(QString path, QString script){
     file.close();
     //ui->outWind->append("Generated");
 
-    //make executable-----------------doesnt work
-    /*QStringList arguments;
-    arguments << "-c" << "chmod a+x "+path;
+}
+void MainWindow::executable(QString path){ //wish there was a way to preserve permissions over scp...
+    QStringList args;
+    args << "-c" << "sudo chmod a+x "+path;
     QProcess* exer = new QProcess(this);
-    exer->start("/bin/sh", arguments);
+    exer->start("/bin/sh", args);
     exer->waitForFinished();
-    exer->terminate();*/
- }
+    exer->terminate();
+}
+
+
 
 void MainWindow::on_streambut_clicked()
 {
-    if(!alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text())){          //if file hasnt been generated previously, then flag.
-        sdpgenerated = false;
-        notify("Please generate and send a new file, then stream", false);
+    int cind = ui->vidsink->currentIndex();
+    if(ui->filesinkname->text()=="" && (cind==3 || cind==4)){ //if filesink and blank
+        notify("Fill out filename first", false);
     }
-    else if(alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text())){          //if file hasnt been generated previously, then flag.
-        sdpgenerated = true;
-
-        if(ui->type1->currentIndex()==0 && ui->camera1->currentIndex()==0){  //video and back
-            cambackyes=true; //is it back camera, yes
-            if(helpScreen){
-                helpScreen=false;
-                notify("Please Calibrate Back Camera",false);
-                QString controls = "*Slide open camera lens-cap \n*Wait for Camera app to launch.\n*Soft press the camera button to focus until satisfied\n*Keeping the lens-cap open, close the Camera app\n*Once ready, press Stream button again";
-                notify(controls,true);
+    else{
+        if((cind!=0 )&& (!alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text()))){   //if not VLC or file hasnt been generated previously, then flag.
+            sdpgenerated = false;
+            if(ui->type1->currentIndex()!=1 && cind!=3){ //if not audio and not filesink
+                notify("Please generate and send a new file, then stream", false);
             }
-            else{
-                streamProcess1();
+            else { //local file streams
+                helper();
             }
         }
-        else {
-            cambackyes=false;
-            streamProcess1();
+        else if((cind==0) || (alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text()))){
+            helper();
         }
-
     }
 }
 
+void MainWindow::helper(){
+    if(ui->type1->currentIndex()==0 && ui->camera1->currentIndex()==0){  //video and back
+        cambackyes=true; //is it back camera, yes
+        if(helpScreen){
+            helpScreen=false;
+            notify("Please Calibrate Back Camera",false);
+            QString controls = "*Slide open camera lens-cap \n*Wait for Camera app to launch.\n*Soft press the camera button to focus until satisfied\n*Keeping the lens-cap open, close the Camera app\n*Once ready, press Stream button again";
+            notify(controls,true);
+        }
+        else{
+            streamProcess1();
+        }
+    }
+    else {
+        cambackyes=false;
+        streamProcess1();
+    }
+}
+
+
 
 void MainWindow::writeSettings(){
     QSettings settings("daUser", "tester");
@@ -169,25 +197,30 @@ void MainWindow::applySettings(){
 }
 
 void MainWindow::streamProcess1(){
-    hostname = ui->address1->text();
-    portnum = ui->port1->text();
-    //getting the size
-    QString currentsize = ui->size1->currentText();
-    if(currentsize == "Custom"){
-        currentsize = ui->custom1->text();
-    }
-    //blanking out windows while streaming
-    ui->stopsream->show(); ui->streambut->hide();
-    showWin(false);
-    //splitting the string
-    QStringList sized = currentsize.split("x");
-    widthnum = sized[0];
-    heightnum = sized[1];
-    int currOutput = ui->vidsink->currentIndex();
-    //LED
-    ledON(true);
+    if(videoyes){
+        hostname = ui->address1->text();
+        portnum = ui->port1->text();
+        //getting the size
+        QString currentsize = ui->size1->currentText();
+        if(currentsize == "Custom"){
+            currentsize = ui->custom1->text();
+        }
+        //blanking out windows while streaming
+        ui->stopsream->show(); ui->streambut->hide();
+        showWin(false);
+        //splitting the string
+        QStringList sized = currentsize.split("x");
+        widthnum = sized[0];
+        heightnum = sized[1];
+        int currOutput = ui->vidsink->currentIndex();
+        //LED
+        ledON(true);
 
-    makeStream(hostname,cambackyes,videoyes,portnum,widthnum,heightnum, currOutput);
+        makeStream(hostname,cambackyes,videoyes,portnum,widthnum,heightnum, currOutput);
+    }
+    else if(!videoyes){
+        notify("feature temporarily disabled for this update.", false);
+    }
 }
 
 void MainWindow::showWin(bool hid){
@@ -313,9 +346,7 @@ void MainWindow::on_type1_activated(int index) //link on cmera1_activated into t
     //Show Addres
     ui->labAddr->show(); ui->address1->show(); ui->labPort->show();; ui->port1->show();
     if(index==1){ //Audio
-        vidoutput= "VLC sdp";
-        ui->sdpgen->setText("Generate "+vidoutput+" file");
-        ui->scpbutton->setText("Send "+vidoutput+" to Linux PC"); //fixes error where audio sdpgen shows webscript instead.
+        ui->outWind->setText("Nothing to generate. Hit stream.");
         ui->labCam->hide();
         ui->labsize->hide();
         ui->camera1->hide();
@@ -331,6 +362,10 @@ void MainWindow::on_type1_activated(int index) //link on cmera1_activated into t
         ui->qcontrol->hide();
         ui->labfilenam->hide();
         ui->filesinkname->hide();
+
+        ui->scpbutton->hide();
+        ui->sdpgen->hide();
+
         videoyes = false;
     }
     else { //Video
@@ -342,6 +377,7 @@ void MainWindow::on_type1_activated(int index) //link on cmera1_activated into t
         ui->labvidsink->show();
         ui->vol->hide();
         ui->labvol->hide();
+        ui->tickqual->show();
         on_tickqual_toggled(ui->tickqual->checkState());
         on_vidsink_activated(ui->vidsink->currentIndex());
         on_camera1_activated(ui->camera1->currentIndex()); ///CORRECT?
@@ -411,26 +447,24 @@ void MainWindow::on_sdpgen_clicked()
     //sdpyes = false;
     QString localip=getIP();
     ui->outWind->setText("Local IP is "+localip);
-    QString decoder;QString typer;
+    //QString decoder;QString typer;
     int outpp = ui->vidsink->currentIndex();
 
-    if(outpp==0){ //VLC
-        if(videoyes){ typer = "video"; decoder ="H264/90000";}
-        else if(!videoyes){ typer="audio"; decoder="MP4A-LATM/48000/2";}
-        currentFile ="/home/user/MyDocs/n900"+typer+"strm.sdp";
-        write2file(currentFile,"v=0\nm="+typer+" "+ui->port1->text()+" RTP/AVP 96\nc=IN IP4 "+localip+"\na=rtpmap:96 "+decoder); //VLC
-
+    if(outpp==0){ //VLC   <------Needs hiding
+        notify("Don't need to generate anything for VLC", false);
+        ui->outWind->clear();
     }
     else if(outpp==1) { //Xout
         currentFile = "/home/user/MyDocs/n900Xvideo.sh";
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+"  ! jpegdec ! autovideosink"); //Xout
-
+        ui->outWind->append("Generated file at: "+currentFile);
     }
     else if(outpp==2) { //webcam
         currentFile = "/home/user/MyDocs/n900Webvideo.sh";
         //write2file(currentFile,"gst-launch-0.10 udpsrc port="+ui->port1->text()+" ! smokedec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0");  //webcam
         //Using Jpeg for now, higer quality?
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+"  ! jpegdec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0"); //Xout
+        ui->outWind->append("Generated file at: "+currentFile);
 
     }
     else if(outpp==3) {//filesink --generate button hidden for this, but just in case.
@@ -441,6 +475,7 @@ void MainWindow::on_sdpgen_clicked()
     else if(outpp==4){//remote filesink
         currentFile = "/home/user/MyDocs/n900FileSave.sh";
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+" ! jpegdec ! ffenc_mpeg2video ! filesink location=/home/"+ui->usernam->text()+"/Desktop/"+ui->filesinkname->text()+".mpg");
+        ui->outWind->append("Generated file at: "+currentFile);
 
     }
     //alreadygen.append(outpp) //old integer method
@@ -466,15 +501,16 @@ void MainWindow::ledON(bool led){
 
 void MainWindow::on_stopsream_clicked()
 {
-    QProcess*terminator = new QProcess();
-    terminator->start("killall gst-launch-0.10");
-    terminator->waitForFinished();
-    terminator->terminate();
+    QProcess*terminator1 = new QProcess();
+    terminator1->start("killall gst-launch-0.10 socat");
+    terminator1->waitForFinished();
+    terminator1->terminate();
+
     //Turn off LED
     ledON(false);
     //
     ui->outWind->clear();
-    ui->outWind->append("Stopped Steaming");
+    ui->outWind->append("Stopped Streaming");
     ui->stopsream->hide();
     ui->streambut->show();
     //making everything visible
@@ -489,7 +525,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 
    //Deletes all generated files
    QStringList arguments1;
-   arguments1 << "-c" << "sudo rm -f /home/user/MyDocs/n900videostrm.sdp /home/user/MyDocs/n900audiostrm.sdp /home/user/MyDocs/n900Xvideo.sh /home/user/MyDocs/n900Webvideo.sh /home/user/MyDocs/n900FileSave.sh /home/user/.scp";
+   arguments1 << "-c" << "sudo rm -f /home/user/MyDocs/n900videostrm.sdp /home/user/MyDocs/n900audiostrm.sdp /home/user/MyDocs/n900Xvideo.sh /home/user/MyDocs/n900Webvideo.sh /home/user/MyDocs/n900FileSave.sh /home/user/.scp /home/user/.httpstream";
    QProcess*process2 = new QProcess(this);
    process2->start("/bin/sh", arguments1);
    process2->waitForFinished();
@@ -518,16 +554,13 @@ void MainWindow::on_scpsend_clicked()
     ui->scpsend->setStyleSheet("QPushButton {background-color : white; color : black;}");    
 }
 
-void MainWindow::on_vidsink_activated(int index)  //this is messy.
+void MainWindow::on_vidsink_activated(int index)  //First part is for showing the filename widgets
 {
     if(index==3 || index==4){//File
         ui->labfilenam->show();
         ui->filesinkname->show();
         ui->tickqual->show();
-        if(ui->filesinkname->text()==""){
-            notify("Please fill out filename", false);
-        }
-        if(index==3){
+        if(index==3){ //local
             ui->sdpgen->hide();
             ui->scpbutton->hide();
             ui->labfilenam->setText("     Filename (/home/user/MyDocs/.videos/):");
@@ -538,22 +571,26 @@ void MainWindow::on_vidsink_activated(int index)  //this is messy.
 
         }
         if(index==4) {
-            //ui->sdpgen->show();
+            if(debugclicked){ui->sdpgen->show();}  //error when switching from local file to remote file.
             ui->labfilenam->setText("    Remote Filename:");
             vidoutput="RemoteFilescript";
             ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
+            ui->outWind->setText("Fill out filename and then generate");
         }
 
     } else if(index!=3 || index!=4){
+
         ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
         ui->labfilenam->hide();
         ui->filesinkname->hide();
         if(debugclicked){ui->sdpgen->show();}// stops it appearing when showdebug hasnt been clicked yet
         if(index==0){
-            vidoutput = "VLC sdp";
-            ui->tickqual->hide();
-            ui->qcontrol->hide();
+            ui->sdpgen->hide();
+            ui->scpbutton->hide();
+            ui->outWind->setText("Nothing needed to generate or send. \nPlease hit Stream.");
+            sdpgenerated = true; //doesnt need to generate one.
         } else {
+            ui->outWind->setText("Please generate and send");
             ui->tickqual->show();
             if(index==1){vidoutput = "Xscript";}
             if(index==2){vidoutput="Webscript";}
@@ -589,5 +626,6 @@ void MainWindow::on_tickqual_toggled(bool checked)
 Removed sdpyes (which did nothing) ----marybe it did!
 You have some global strings widthnum, which aren't used anywhere else. hostname should be used more than once(though updated at generating stage).
 Delete generated files from device upon sending.
+Added quality control to VLC
 
 */
